require

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CheckResult

type CheckResult struct {
	Condition string
	Passed    bool
	Message   string
}

CheckResult describes the outcome of a single @require evaluation.

func Evaluate

func Evaluate(repoRoot string, target *parser.Target) []CheckResult

Evaluate runs all @require directives on a target and returns any that failed. Returns nil if all requirements are met or the target has no @require directives.

Jump to