Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Directive ¶
type Directive struct {
Name string // "require", "mcp", "skill", "network", "no-sandbox"
Args string
}
Directive represents a modifier on a target (e.g. @require, @mcp, @skill, @network, @no-sandbox).
type Target ¶
type Target struct {
Name string
Dependencies []string
Recipe string
Model string // per-target model override
Directives []Directive
}
Target represents a single target definition in a Vibefile.
func (*Target) DirectiveArgs ¶
DirectiveArgs returns the args for the first directive with the given name, or empty string.
func (*Target) ExecutionMode ¶
ExecutionMode returns the execution mode for this target based on its directives.
func (*Target) HasDirective ¶
HasDirective checks whether the target has a directive with the given name.
Click to show internal directories.
Click to hide internal directories.